==============================
Providing options for trackers
==============================

.. report:: Trackers.TrackerWithOptions
   :render: table
   :tracker: option_int=2, option_string=testA

   A tracker with an option.

.. report:: Trackers.TrackerWithOptions
   :render: table
   :tracker: option_int=4, option_string=testB

   Same tracker, different options

.. report:: Trackers.TrackerWithOptions
   :render: table

   Same tracker, without options


